package cn.iocoder.yudao.module.wealth.service.receiptInvoice;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.util.MyBatisUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.LoginUser;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.wealth.convert.receiptInvoice.ReceiptInvoiceConvert;
import cn.iocoder.yudao.module.wealth.convert.receivable.ReceivableConvert;
import cn.iocoder.yudao.module.wealth.dal.dataobject.receiptInvoice.ReceiptInvoiceDO;
import cn.iocoder.yudao.module.wealth.dal.dataobject.receiptInvoiceLog.ReceiptInvoiceLogDO;
import cn.iocoder.yudao.module.wealth.dal.dataobject.receivable.ReceivableDO;
import cn.iocoder.yudao.module.wealth.dal.mysql.receiptInvoice.ReceiptInvoiceMapper;
import cn.iocoder.yudao.module.wealth.dal.mysql.receiptInvoiceLog.ReceiptInvoiceLogMapper;
import cn.iocoder.yudao.module.wealth.dal.mysql.receivable.ReceivableMapper;
import cn.iocoder.yudao.module.wealth.enums.InvoicingLinkEnum;
import cn.iocoder.yudao.module.wealth.vo.receiptInvoice.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.Date;
import java.util.List;

/**
 * 收款单开票信息 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class ReceiptInvoiceServiceImpl extends AbstractService<ReceiptInvoiceMapper, ReceiptInvoiceDO> implements ReceiptInvoiceService {

    @Resource
    private ReceiptInvoiceMapper receiptInvoiceMapper;
    @Resource
    private ReceiptInvoiceLogMapper receiptInvoiceLogMapper;
    @Resource
    private ReceivableMapper receivableMapper;

    @Override
    public Long createReceiptInvoice(ReceiptInvoiceCreateReqVO createReqVO) {
        // 插入
        ReceiptInvoiceDO receiptInvoice = ReceiptInvoiceConvert.INSTANCE.convert(createReqVO);
        receiptInvoiceMapper.insert(receiptInvoice);
        // 返回
        return receiptInvoice.getId();
    }

    @Override
    public void updateReceiptInvoice(ReceiptInvoiceUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateReceiptInvoiceExists(updateReqVO.getId());
        // 更新
        ReceiptInvoiceDO updateObj = ReceiptInvoiceConvert.INSTANCE.convert(updateReqVO);
        receiptInvoiceMapper.updateById(updateObj);
    }

    @Override
    public void deleteReceiptInvoice(Long id) {
        // 校验存在
        this.validateReceiptInvoiceExists(id);
        // 删除
        receiptInvoiceMapper.deleteById(id);
    }

    private void validateReceiptInvoiceExists(Long id) {
        if (receiptInvoiceMapper.selectById(id) == null) {
            //throw exception(RECEIPT_INVOICE_NOT_EXISTS);
        }
    }

    @Override
    public ReceiptInvoiceDetailVO getReceiptInvoiceDetail(Long id) {
        ReceiptInvoiceDetailVO receiptInvoiceDetail = receiptInvoiceMapper.getReceiptInvoiceDetail(id);
        if (receiptInvoiceDetail == null) {
            return null;
        }
        List<ReceiptInvoiceLogDO> invoiceLogDOS = receiptInvoiceLogMapper.selectList("invoice_id", id);
        receiptInvoiceDetail.setInvoiceLog(ReceiptInvoiceConvert.INSTANCE.logDOtoLogVOList(invoiceLogDOS));
        List<ReceivableDO> receivableDOS = receivableMapper.selectList(Wrappers.<ReceivableDO>lambdaQuery().eq(ReceivableDO::getReceiptId, receiptInvoiceDetail.getReceiptId()));
        receiptInvoiceDetail.setReceivableList(ReceivableConvert.INSTANCE.convertList(receivableDOS));
        return receiptInvoiceDetail;
    }

    @Override
    public List<ReceiptInvoiceDO> getReceiptInvoiceList(Collection<Long> ids) {
        return receiptInvoiceMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<ReceiptInvoicePageBackVO> getReceiptInvoicePage(ReceiptInvoiceQueryVO query, PageVO page) {
        IPage<ReceiptInvoicePageBackVO> mpPage = MyBatisUtils.buildPage(page);
        receiptInvoiceMapper.getReceiptInvoicePage(mpPage, query);
        return PageResult.of(mpPage);
    }

    @Override
    public List<ReceiptInvoiceDO> getReceiptInvoiceList(ReceiptInvoiceQueryVO query) {
        return receiptInvoiceMapper.selectList(query);
    }

    @Override
    public Boolean rejectInvoiceInfo(ReceiptInvoiceOperateReqVO rejectReqVO) {
        return null;
    }

    @Override
    public Boolean cancelInvoice(ReceiptInvoiceOperateReqVO rejectReqVO) {
        return null;
    }

    @Override
    public Boolean deleteInvoice(ReceiptInvoiceOperateReqVO rejectReqVO) {
        return null;
    }

    /**
     * 记录日志
     */
    private void recordLog(Long invoiceId, InvoicingLinkEnum linkEnum, String remark, Integer bpmStatus) {
        LoginUser user = SecurityFrameworkUtils.getLoginUser();
        String username = "";
        if (user != null && user.getUsername() != null) {
            username = user.getUsername();
        }
        ReceiptInvoiceLogDO receiptInvoiceLogDO = ReceiptInvoiceLogDO.builder()
                .invoiceId(invoiceId)
                .operator(username)
                .remark(remark)
                .invoicingLink(linkEnum.getValue())
                .bpmStatus(bpmStatus)
                .createTime(new Date())
                .build();
        receiptInvoiceLogMapper.insert(receiptInvoiceLogDO);
    }
}
