package cn.iocoder.yudao.module.wealth.util;

import cn.iocoder.yudao.framework.redis.helper.RedisHelper;
import cn.iocoder.yudao.module.wealth.dal.mysql.receiptInvoice.ReceiptInvoiceMapper;
import com.alibaba.excel.util.DateUtils;
import org.redisson.api.RLock;
import org.redisson.api.RedissonClient;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Date;
import java.util.concurrent.TimeUnit;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.infra.enums.ErrorCodeConstants.GET_LOCK_FAILED;

/**
 * 根据规则生成各种code
 */
@Component
public class InvoiceGenCodeUtils {

    @Resource
    private RedisHelper redisHelper;
    @Resource
    private RedissonClient redissonClient;
    @Resource
    private ReceiptInvoiceMapper receiptInvoiceMapper;

    /**
     * 生成发票编号
     */
    public String generateInvoiceCode() {
        // KP+年月日+4位流水号；例如：KP24061200001
        String key = "invoice:max:number";
        StringBuilder code = new StringBuilder();
        code.append("KP");
        code.append(DateUtils.format(new Date(), "yyMMdd"));
        Long codeNum;
        if (redisHelper.hasKey(key)) {
            codeNum = redisHelper.incrBy(key, 1);
        } else {
            RLock lock = redissonClient.getLock("next:invoice:code:lock");
            try {
                boolean lockSuccess = lock.tryLock(2, 2, TimeUnit.SECONDS);
                if (!lockSuccess) {
                    throw exception(GET_LOCK_FAILED);
                }
                String currentMaxInvoiceCode = receiptInvoiceMapper.getCurrentMaxInvoiceCode();
                if (currentMaxInvoiceCode == null){
                    codeNum = 1L;
                } else {
                    codeNum = Long.parseLong(currentMaxInvoiceCode.substring(7)) + 1;
                }
                redisHelper.set(key, String.valueOf(codeNum),10, TimeUnit.SECONDS);
            } catch (InterruptedException e) {
                throw exception(GET_LOCK_FAILED);
            } finally {
                lock.unlock();
            }
        }
        // 获得4位序列号，不足位前面补0
        codeNum = codeNum % 10000;
        code.append(String.format("%04d", codeNum));
        return code.toString();
    }
}
