package cn.iocoder.yudao.module.wealth.vo.receipt;

import com.alibaba.excel.annotation.ExcelProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

/**
 * 收款单 Response VO
 *
 * @author 郑屹
 */
@Data
@ApiModel("管理后台 - 收款单 Response VO")
public class ReceiptBackVO {

    @ExcelProperty("主键")
    @ApiModelProperty(value = "主键", required = true)
    private Long id;

    @ExcelProperty("收款单号（例：SKD001）")
    @ApiModelProperty(value = "收款单号（例：SKD001）", required = true)
    private String receiptNo;

    @ExcelProperty("部门Id")
    @ApiModelProperty(value = "部门Id")
    private Long departmentId;

    @ExcelProperty("部门名称")
    @ApiModelProperty(value = "部门名称")
    private String departmentName;

    @ExcelProperty("业务员")
    @ApiModelProperty(value = "业务员")
    private Long salesmanId;

    @ExcelProperty("业务员名称")
    @ApiModelProperty(value = "业务员名称")
    private String salesmanName;

    @ExcelProperty("客户id")
    @ApiModelProperty(value = "客户id")
    private Long customerId;

    @ExcelProperty("客户名称")
    @ApiModelProperty(value = "客户名称")
    private String customerName;

    @ExcelProperty("备注")
    @ApiModelProperty(value = "备注")
    private String remark;

    @ExcelProperty("核销币种")
    @ApiModelProperty(value = "核销币种")
    private Long currencyId;

    @ApiModelProperty(value = "核销比例显示要除以100")
    private BigDecimal writeOffProportion;

    @ApiModelProperty(value = "核销金额")
    private Long writeOffAmount;

    @ExcelProperty("应收总金额")
    @ApiModelProperty(value = "应收总金额")
    private java.math.BigDecimal receivableTotalAmount;

    @ExcelProperty("手续费")
    @ApiModelProperty(value = "手续费")
    private java.math.BigDecimal feeRate;

    @ExcelProperty("发票抬头")
    @ApiModelProperty(value = "发票抬头")
    private String invoice;

    @ExcelProperty("纳税人识别号")
    @ApiModelProperty(value = "纳税人识别号")
    private String taxpayer;

    @ExcelProperty("开户行")
    @ApiModelProperty(value = "开户行")
    private String accountBank;

    @ExcelProperty("账号")
    @ApiModelProperty(value = "账号")
    private String accountName;

    @ExcelProperty("项目")
    @ApiModelProperty(value = "项目")
    private String projectName;

    @ExcelProperty("税率")
    @ApiModelProperty(value = "税率")
    private java.math.BigDecimal taxRate;

    @ExcelProperty("开票地址、电话")
    @ApiModelProperty(value = "开票地址、电话")
    private String addressPhone;

    @ExcelProperty("实收日期")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "实收日期")
    private Date payedAt;

    @ExcelProperty("发票号码")
    @ApiModelProperty(value = "发票号码")
    private String invoiceNumber;

    @ExcelProperty("开票类型(字典表 invoicing_type)")
    @ApiModelProperty(value = "开票类型(字典表 invoicing_type)")
    private Integer invoicingTypeId;

    @ExcelProperty("开票类型名称")
    @ApiModelProperty(value = "开票类型名称")
    private String invoicingType;

    @ExcelProperty("开票备注")
    @ApiModelProperty(value = "开票备注")
    private String invoicingRemark;

    @ExcelProperty("通知人id")
    @ApiModelProperty(value = "通知人id")
    private Long noticeAdminId;

    @ExcelProperty("通知人名称")
    @ApiModelProperty(value = "通知人名称")
    private String noticeAdminName;

    @ExcelProperty("收款人id")
    @ApiModelProperty(value = "收款人id")
    private Long payeeId;

    @ExcelProperty("收款人名称")
    @ApiModelProperty(value = "收款人名称")
    private String payeeName;

    @ExcelProperty("核销人id")
    @ApiModelProperty(value = "核销人id")
    private Long writeOffId;

    @ExcelProperty("核销人名称")
    @ApiModelProperty(value = "核销人名称")
    private String writeOffName;

    @ExcelProperty("开票人id")
    @ApiModelProperty(value = "开票人id")
    private Long issuerId;

    @ExcelProperty("开票人名称")
    @ApiModelProperty(value = "开票人名称")
    private String issuerName;

    @ExcelProperty("状态: 0:草稿， 1待收款， 2待核销，3已部分核销，4已核销，5已核销待开票，6已开票 7审核中 8审核失败 9反审核中 10全部核销中 11反核销审核中")
    @ApiModelProperty(value = "状态: 0:草稿， 1待收款， 2待核销，3已部分核销，4已核销，5已核销待开票，6已开票 7审核中 8审核失败 9反审核中 10全部核销中 11反核销审核中")
    private Integer state;

    @ExcelProperty("核销时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "核销时间")
    private Date writeOffAt;

    @ExcelProperty("开票时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "开票时间")
    private Date invoicingAt;

    @ExcelProperty("数据来源（pc端，mobile端）")
    @ApiModelProperty(value = "数据来源（pc端，mobile端）")
    private String source;

    @ExcelProperty("创建时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "创建时间")
    private Date createTime;

    @ExcelProperty("是否需要开票")
    @ApiModelProperty(value = "是否需要开票0-不需要1需要")
    private Integer openInvoice;

    @ExcelProperty("汇率有效期")
    @ApiModelProperty(value = "汇率有效期")
    private Date rateValidateDate;

    @ExcelProperty("当前流程ID")
    @ApiModelProperty(value = "当前流程ID")
    private String bmpId;

    @ApiModelProperty(value = "驳回原因")
    private String comment;

    @ApiModelProperty(value = "财务备注")
    private String financeRemark;

    @ExcelProperty("明细状态")
    @ApiModelProperty(value = "明细状态")
    private String mxStatus;

    @ApiModelProperty(value = "订单号")
    private String orderNo;

    @ApiModelProperty(value = "订单ID")
    private Long orderId;

    @ApiModelProperty(value = "提单号")
    private String tidanNo;

    @ApiModelProperty(value = "应收金额")
    private String ysShow;

    @ApiModelProperty(value = "实数金额")
    private String ssShow;

    @ApiModelProperty(value = "核销比例")
    private String hxBiLi;

    @ApiModelProperty(value = "明细状态（数据库）")
    private Integer detailStatus;

    @ApiModelProperty(value = "开票状态")
    private Integer invoicingStatus;

    @ApiModelProperty(value = "开票资料状态")
    private Integer invoiceDataStatus;
}
