package cn.iocoder.yudao.module.wealth.vo.receivable;

import com.alibaba.excel.annotation.ExcelProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

/**
 * 应收款 Response VO
 *
 * @author 郑屹
 */
@Data
@ApiModel("管理后台 - 应收款 Response VO")
public class ReceivableBackVO {

    @ExcelProperty("主键")
    @ApiModelProperty(value = "主键", required = true)
    private Long id;

    @ExcelProperty("收款单id")
    @ApiModelProperty(value = "收款单id")
    private Long receiptId;

    @ExcelProperty("收款单号")
    @ApiModelProperty(value = "收款单号")
    private String receiptNo;

    @ExcelProperty("订单id")
    @ApiModelProperty(value = "订单id")
    private Long orderId;

    @ExcelProperty("订单号")
    @ApiModelProperty(value = "订单号")
    private String orderNo;

    @ExcelProperty("自编号")
    @ApiModelProperty(value = "自编号")
    private String containerNumber;

    @ExcelProperty("订单项商品ID")
    @ApiModelProperty(value = "订单项商品ID")
    private Long orderItemId;

    @ExcelProperty("中文标题")
    @ApiModelProperty(value = "中文标题")
    private String titleZh;

    @ExcelProperty("英文标题")
    @ApiModelProperty(value = "英文标题")
    private String titleEn;

    @ExcelProperty("数量")
    @ApiModelProperty(value = "数量")
    private Integer quantity;

    @ExcelProperty("箱数")
    @ApiModelProperty(value = "箱数")
    private Integer num;

    @ExcelProperty("体积/重量")
    @ApiModelProperty(value = "体积/重量")
    private BigDecimal weight;

    @ExcelProperty("体积")
    @ApiModelProperty(value = "体积")
    private BigDecimal volume;

    @ExcelProperty("收款类型(字典 payment_type)")
    @ApiModelProperty(value = "收款类型(字典 payment_type)")
    private Integer collectionType;

    @ExcelProperty("费用类型(字典 receivable_fee_type)")
    @ApiModelProperty(value = "费用类型(字典 receivable_fee_type)")
    private Integer feeType;

    @ApiModelProperty(value = "费用类型描述")
    private String feeTypeLabel;

    @ApiModelProperty(value = "费用类型英文描述")
    private String feeTypeLabelEn;

    @ExcelProperty("汇率")
    @ApiModelProperty(value = "汇率")
    private BigDecimal exchangeRate;

    @ExcelProperty("货币id")
    @ApiModelProperty(value = "货币id")
    private Long currencyId;

    @ExcelProperty("单价")
    @ApiModelProperty(value = "单价")
    private BigDecimal unitPrice;

    @ExcelProperty("总金额")
    @ApiModelProperty(value = "总金额")
    private BigDecimal totalAmount;

    @ExcelProperty("优惠金额")
    @ApiModelProperty(value = "优惠金额")
    private BigDecimal discountTotal;

    @ExcelProperty("优惠备注")
    @ApiModelProperty(value = "优惠备注")
    private String discountRemark;

    @ApiModelProperty(value = "是否预付：0 到付 1 预付")
    private Integer isPayAdvance;

    @ExcelProperty("收款状态（0未收款，1收款中，2已收款）")
    @ApiModelProperty(value = "收款状态（0未收款，1收款中，2已收款）")
    private Integer state;

    @ExcelProperty("数据来源（pc端，mobile端）")
    @ApiModelProperty(value = "数据来源（pc端，mobile端）")
    private String source;

    @ExcelProperty("作者")
    @ApiModelProperty(value = "作者")
    private String author;

    @ExcelProperty("创建时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "创建时间", required = true)
    private Date createTime;

    @ExcelProperty("唛头")
    @ApiModelProperty(value = "唛头")
    private String marks;

    @ApiModelProperty(value = "订单状态详情见字典：order_status")
    private Integer status;

    @ApiModelProperty(value = "订单异常状态(字典 order_abnormal_state)")
    private Integer abnormalState;

    @ApiModelProperty(value = "订单入仓状态(字典 order_warehouse_in_status)")
    private Integer inWarehouseState;

    @ApiModelProperty(value = "订单出货状态(字典 order_shipment_state)")
    private Integer shipmentState;

    @ApiModelProperty(value = "订单到仓状态(字典 order_to_warehouse_state)")
    private Integer toWarehouseState;

    @ApiModelProperty(value = "发货人id")
    private String consignorId;

    @ExcelProperty("发货人姓名")
    @ApiModelProperty(value = "发货人姓名")
    private String consignorName;

    @ExcelProperty("发货人手机")
    @ApiModelProperty(value = "发货人手机号")
    private String consignorPhone;

    @ApiModelProperty(value = "收货人id")
    private String consigneeId;

    @ExcelProperty("收货人姓名")
    @ApiModelProperty(value = "收货人姓名")
    private String consigneeName;

    @ExcelProperty("收货人手机")
    @ApiModelProperty(value = "收货人手机号")
    private String consigneePhone;

    @ExcelProperty("运输方式id")
    @ApiModelProperty(value = "运输方式id")
    private String transportId;

    @ExcelProperty("出货渠道ID")
    @ApiModelProperty(value = "出货渠道ID")
    private String channelId;

    @ExcelProperty("始发地ID")
    @ApiModelProperty(value = "始发地ID")
    private String departureId;

    @ExcelProperty("目的地ID")
    @ApiModelProperty(value = "目的地ID")
    private String objectiveId;

    @ExcelProperty("目的地名称")
    @ApiModelProperty(value = "目的地名称中文")
    private String objectiveNameZh;

    @ExcelProperty("目的地名称英文")
    @ApiModelProperty(value = "目的地名称英文")
    private String objectiveNameEn;

    @ApiModelProperty(value = "货值")
    private BigDecimal amountWorth;

    @ApiModelProperty(value = "提单")
    private String tidanNo;

    @ApiModelProperty(value = "付款人1:发货人 2:收货人")
    private String paymentUser;

    @ApiModelProperty(value = "费用来源：1 订单计算 2 费用申请 3 特需费用")
    private Integer feeSource;

    @ApiModelProperty(value = "税点")
    private BigDecimal taxPoint;

    @ApiModelProperty(value = "含税金额")
    private BigDecimal taxAmount;

    @ApiModelProperty(value = "不含税金额")
    private BigDecimal notIncludedTaxAmount;

    @ApiModelProperty(value = "核销比例")
    private BigDecimal writeOffProportion;

    @ApiModelProperty(value = "基准金额")
    private BigDecimal baseAmount;

     @ApiModelProperty(value = "实际金额")
    private BigDecimal actualAmount;

}
